@@ -7,7 +7,7 @@ use warnings;
 
 use Scalar::Util qw(reftype refaddr blessed);
 
-our $VERSION = '1.24';
+our $VERSION = '1.25';
 my $XS_VERSION = $VERSION;
 $VERSION = eval $VERSION;
 
@@ -133,10 +133,6 @@ $make_shared = sub {
     elsif ($ref_type eq 'SCALAR') {
         $copy = \do{ my $scalar = $$item; };
         share($copy);
-        # Clone READONLY flag
-        if (Internals::SvREADONLY($$item)) {
-            Internals::SvREADONLY($$copy, 1);
-        }
         # Add to clone checking hash
         $cloned->{$addr} = $copy;
     }
@@ -169,8 +165,13 @@ $make_shared = sub {
     }
 
     # Clone READONLY flag
+    if ($ref_type eq 'SCALAR') {
+        if (Internals::SvREADONLY($$item)) {
+            Internals::SvREADONLY($$copy, 1) if ($] >= 5.008003);
+        }
+    }
     if (Internals::SvREADONLY($item)) {
-        Internals::SvREADONLY($copy, 1);
+        Internals::SvREADONLY($copy, 1) if ($] >= 5.008003);
     }
 
     return $copy;
@@ -186,7 +187,7 @@ threads::shared - Perl extension for sharing data structures between threads
 
 =head1 VERSION
 
-This document describes threads::shared version 1.24
+This document describes threads::shared version 1.25
 
 =head1 SYNOPSIS
 
@@ -540,7 +541,7 @@ L<threads::shared> Discussion Forum on CPAN:
 L<http://www.cpanforum.com/dist/threads-shared>
 
 Annotated POD for L<threads::shared>:
-L<http://annocpan.org/~JDHEDDEN/threads-shared-1.24/shared.pm>
+L<http://annocpan.org/~JDHEDDEN/threads-shared-1.25/shared.pm>
 
 Source repository:
 L<http://code.google.com/p/threads-shared/>
